searchData={"items":[{"type":"module","title":"SNMP","doc":"An SNMP client library for Elixir.","ref":"SNMP.html"},{"type":"function","title":"SNMP.bulkwalk/2","doc":"Performs a SNMP BULKWALK operation, efficiently retrieving a subtree of MIB objects.","ref":"SNMP.html#bulkwalk/2"},{"type":"function","title":"Parameters - SNMP.bulkwalk/2","doc":"- request: Map containing uri, credential, and varbinds\n- options: Keyword list of options including max_repetitions and timeout","ref":"SNMP.html#bulkwalk/2-parameters"},{"type":"function","title":"Returns - SNMP.bulkwalk/2","doc":"- List of varbinds in the requested subtree","ref":"SNMP.html#bulkwalk/2-returns"},{"type":"function","title":"SNMP.credential/1","doc":"Returns a keyword list containing the given SNMP\ncredentials.","ref":"SNMP.html#credential/1"},{"type":"function","title":"Example - SNMP.credential/1","doc":"iex> SNMP.credential(%{community: \"public\"})\n    %SNMP.CommunityCredential{version: :v1, sec_model: :v1, community: ~c\"public\"}\n\n    iex> SNMP.credential(\n    ...>   %{version: :v2, community: \"public\"}\n    ...> )\n    %SNMP.CommunityCredential{version: :v2, sec_model: :v2c, community: ~c\"public\"}\n\n    iex> SNMP.credential(%{sec_name: \"user\"})\n    %SNMP.USMCredential{\n      version: :v3,\n      sec_model: :usm,\n      sec_level: :noAuthNoPriv,\n      sec_name: ~c\"user\",\n      auth: :usmNoAuthProtocol,\n      auth_pass: nil,\n      priv: :usmNoPrivProtocol,\n      priv_pass: nil\n    }\n\n\n    iex> SNMP.credential(\n    ...>   %{sec_name: \"user\",\n    ...>     auth: :sha,\n    ...>     auth_pass: \"authpass\",\n    ...>   }\n    ...> )\n    %SNMP.USMCredential{\n      version: :v3,\n      sec_model: :usm,\n      sec_level: :authNoPriv,\n      sec_name: ~c\"user\",\n      auth: :usmHMACSHAAuthProtocol,\n      auth_pass: ~c\"authpass\",\n      priv: :usmNoPrivProtocol,\n      priv_pass: nil\n    }\n\n\n    iex> SNMP.credential(\n    ...>   %{sec_name: \"user\",\n    ...>     auth: :sha,\n    ...>     auth_pass: \"authpass\",\n    ...>     priv: :aes,\n    ...>     priv_pass: \"privpass\",\n    ...>   }\n    ...> )\n    %SNMP.USMCredential{\n      version: :v3,\n      sec_model: :usm,\n      sec_level: :authPriv,\n      sec_name: ~c\"user\",\n      auth: :usmHMACSHAAuthProtocol,\n      auth_pass: ~c\"authpass\",\n      priv: :usmAesCfb128Protocol,\n      priv_pass: ~c\"privpass\"\n    }","ref":"SNMP.html#credential/1-example"},{"type":"function","title":"SNMP.list_oid_to_string/1","doc":"Converts `oid` to dot-delimited string.","ref":"SNMP.html#list_oid_to_string/1"},{"type":"function","title":"Example - SNMP.list_oid_to_string/1","doc":"iex> SNMP.list_oid_to_string([1,3,6,1,2,1,1,5,0])\n    \"1.3.6.1.2.1.1.5.0\"","ref":"SNMP.html#list_oid_to_string/1-example"},{"type":"function","title":"SNMP.load_mib/1","doc":"","ref":"SNMP.html#load_mib/1"},{"type":"function","title":"SNMP.request/2","doc":"Perform an SNMP GET/SET request.","ref":"SNMP.html#request/2"},{"type":"function","title":"Example - SNMP.request/2","doc":"iex> %{uri: URI.parse(\"snmp://an-snmp-host.local\"),\n    ...>   credential: v2_cred,\n    ...>   varbinds: [%{oid: [1,3,6,1,2,1,1,5,0]}],\n    ...> } |> SNMP.request\n    { :ok,\n      [ %{oid: [1, 3, 6, 1, 2, 1, 1, 5, 0],\n          type: :\"OCTET STRING\",\n          value: \"an-snmp-host\"\n        }\n      ]\n    }\n\n    iex> %{uri: URI.parse(\"snmp://an-snmp-host.local\"),\n    ...>   credential: v2_cred,\n    ...>   varbinds: [\n    ...>     %{oid: [1,3,6,1,2,1,1,5,0],\n    ...>       type: :s,\n    ...>       value: \"new-hostname\",\n    ...>     },\n    ...>   ],\n    ...> } |> SNMP.request\n    { :ok,\n      [ %{oid: [1, 3, 6, 1, 2, 1, 1, 5, 0],\n          type: :\"OCTET STRING\",\n          value: \"new-hostname\"\n        }\n      ]\n    }","ref":"SNMP.html#request/2-example"},{"type":"function","title":"SNMP.resolve_object_name_to_oid/1","doc":"","ref":"SNMP.html#resolve_object_name_to_oid/1"},{"type":"function","title":"SNMP.start/0","doc":"","ref":"SNMP.html#start/0"},{"type":"function","title":"SNMP.start/2","doc":"","ref":"SNMP.html#start/2"},{"type":"function","title":"SNMP.string_oid_to_list/1","doc":"Converts dot-delimited `oid` string to list.","ref":"SNMP.html#string_oid_to_list/1"},{"type":"function","title":"Example - SNMP.string_oid_to_list/1","doc":"iex> SNMP.string_oid_to_list(\"1.3.6.1.2.1.1.5.0\")\n    [1,3,6,1,2,1,1,5,0]","ref":"SNMP.html#string_oid_to_list/1-example"},{"type":"function","title":"SNMP.sync_get/3","doc":"","ref":"SNMP.html#sync_get/3"},{"type":"function","title":"SNMP.walk/2","doc":"Perform an SNMP walk using GETNEXT operations.\n\nThis function returns a stream, which ensures that the\nresulting walk is bounded.","ref":"SNMP.html#walk/2"},{"type":"function","title":"Example - SNMP.walk/2","doc":"iex> %{uri: URI.parse(\"snmp://an-snmp-host.local\"),\n    ...>   credential: v3_cred,\n    ...>   varbinds: [%{oid: \"ipAddrTable\"}],\n    ...> } |> SNMP.walk\n    ...> |> Enum.take(1)\n    [ %{oid: [1, 3, 6, 1, 2, 1, 4, 20, 1, 1, 192, 0, 2, 1],\n        type: :IpAddress,\n        value: [192, 0, 2, 1],\n      }\n    ]","ref":"SNMP.html#walk/2-example"},{"type":"type","title":"SNMP.asn1_type/0","doc":"","ref":"SNMP.html#t:asn1_type/0"},{"type":"type","title":"SNMP.asn1_value/0","doc":"","ref":"SNMP.html#t:asn1_value/0"},{"type":"type","title":"SNMP.credential/0","doc":"","ref":"SNMP.html#t:credential/0"},{"type":"type","title":"SNMP.mib_name/0","doc":"","ref":"SNMP.html#t:mib_name/0"},{"type":"type","title":"SNMP.object_id/0","doc":"","ref":"SNMP.html#t:object_id/0"},{"type":"type","title":"SNMP.object_name/0","doc":"","ref":"SNMP.html#t:object_name/0"},{"type":"type","title":"SNMP.req_options/0","doc":"","ref":"SNMP.html#t:req_options/0"},{"type":"type","title":"SNMP.req_params/0","doc":"","ref":"SNMP.html#t:req_params/0"},{"type":"type","title":"SNMP.req_varbind/0","doc":"","ref":"SNMP.html#t:req_varbind/0"},{"type":"type","title":"SNMP.request_result/0","doc":"","ref":"SNMP.html#t:request_result/0"},{"type":"type","title":"SNMP.snmp_credential/0","doc":"","ref":"SNMP.html#t:snmp_credential/0"},{"type":"type","title":"SNMP.varbind/0","doc":"","ref":"SNMP.html#t:varbind/0"},{"type":"module","title":"SNMP.CommunityCredential","doc":"","ref":"SNMP.CommunityCredential.html"},{"type":"type","title":"SNMP.CommunityCredential.t/0","doc":"","ref":"SNMP.CommunityCredential.html#t:t/0"},{"type":"module","title":"SNMP.MIB","doc":"Functions for working with SNMP MIBs.","ref":"SNMP.MIB.html"},{"type":"function","title":"SNMP.MIB.compile/2","doc":"Compile the MIB in `mib_file` with includes from\n`include_paths`.","ref":"SNMP.MIB.html#compile/2"},{"type":"function","title":"SNMP.MIB.compile_all/1","doc":"Compile all .mib files in `mib_dirs`.","ref":"SNMP.MIB.html#compile_all/1"},{"type":"type","title":"SNMP.MIB.include_paths/0","doc":"","ref":"SNMP.MIB.html#t:include_paths/0"},{"type":"type","title":"SNMP.MIB.mib_dir/0","doc":"","ref":"SNMP.MIB.html#t:mib_dir/0"},{"type":"type","title":"SNMP.MIB.mib_file/0","doc":"","ref":"SNMP.MIB.html#t:mib_file/0"},{"type":"module","title":"SNMP.USMCredential","doc":"","ref":"SNMP.USMCredential.html"},{"type":"type","title":"SNMP.USMCredential.t/0","doc":"","ref":"SNMP.USMCredential.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}